#!/bin/bash

# Get the directory of the script
SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"

# Check if Homebrew is installed, install if not
if command -v brew &> /dev/null; then
    echo "You already have Homebrew, great."
else
    echo "Homebrew not found, initiating installation... (Note: This could take up to 10 minutes. Please don't close this window.)"
    /bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install.sh)"
    echo "Success!"
fi

# Check if ffmpeg is installed, install if not
if brew list ffmpeg &> /dev/null; then
    echo "You already have ffmpeg, great."
else
    echo "ffmpeg not detected, proceeding with installation... (Note: This might take a while. Please keep this window open.)"
    brew install ffmpeg
    echo "Success!"
fi

# Check if yt-dlp is installed, install if not
if brew list yt-dlp &> /dev/null; then
    echo "You already have yt-dlp, great."
else
    echo "yt-dlp is missing, starting installation process... (This process could take some time. Do not close this window.)"
    brew install yt-dlp
    echo "Success!"
fi

# Check if python-tk is installed, install if not
if brew list python-tk &> /dev/null; then
    echo "You already have python-tk, great."
else
    echo "python-tk is not installed, beginning installation... (This could take up to 10 minutes. Make sure to not close this window.)"
    brew install python-tk
    echo "Success!"
fi

# Additional commands to run your Python script or any other task can be added here

# Run the Python script
echo "Running gui-ytdler-advanced.py..."
python3 "$SCRIPT_DIR/gui-ytdler-advanced.py"
echo "gui-ytdler-advanced.py has been executed."
