import sys
import os

# Adjust the working directory
if len(sys.argv) > 1:
    os.chdir(sys.argv[1])


import json
import csv
import subprocess
from datetime import datetime
from tkinter import filedialog, Tk, simpledialog, messagebox

def download_youtube_videos(youtube_url, download_path):
    command = f"yt-dlp -f bestvideo+bestaudio -o '{download_path}/%(title)s [uploaded %(upload_date>%Y-%m-%d)s | viewcount %(view_count)s].%(ext)s' --write-description --write-info-json --write-comments --write-sub --write-thumbnail -- '{youtube_url}'"
    subprocess.run(command, shell=True)
    print("Download complete. Please check for the popup window to select the download folder for processing.")
    process_folder(download_path)  # Proceed to process folder after download

def process_folder(directory_path):
    headers = ['Number', 'Video ID', 'Title', 'Upload Date', 'View Count', 'Comment Count', 'Webpage URL', 'Categories']
    video_data = []
    for file_name in os.listdir(directory_path):
        if file_name.endswith('.json'):
            with open(os.path.join(directory_path, file_name), 'r') as file:
                data = json.load(file)
                upload_date = data.get('upload_date', '')
                try:
                    formatted_date = datetime.strptime(upload_date, '%Y%m%d').strftime('%Y-%m-%d')
                    video_data.append([
                        '',
                        data.get('id', ''),
                        data.get('title', ''),
                        formatted_date,
                        "{:,}".format(data.get('view_count', 0)),
                        "{:,}".format(data.get('comment_count', 0)),
                        data.get('webpage_url', ''),
                        ', '.join(data.get('categories', []))
                    ])
                except ValueError:
                    continue
    video_data.sort(key=lambda x: datetime.strptime(x[3], '%Y-%m-%d'))
    for index, row in enumerate(video_data, start=1):
        row[0] = str(index)
    desktop_path = os.path.join(os.path.expanduser('~'), 'Desktop', 'extracted_video_stats.csv')
    with open(desktop_path, 'w', newline='', encoding='utf-8') as csv_file:
        writer = csv.writer(csv_file)
        writer.writerow(headers)
        writer.writerows(video_data)
    messagebox.showinfo("Success", "Data extraction complete. CSV file saved to your desktop.")

def select_folder():
    Tk().withdraw()
    answer = messagebox.askyesno("YouTube Videos", "Have you already downloaded your YouTube videos?")
    if answer:
        messagebox.showinfo("Select Folder", "Please select the folder that contains all the downloads (including files ending in .json).")
        directory_path = filedialog.askdirectory(title="Select Folder")
        if directory_path:
            process_folder(directory_path)
    else:
        youtube_url = simpledialog.askstring("Download", "Enter the YouTube URL:")
        if youtube_url:
            download_path = filedialog.askdirectory(title="Select Download Folder", 
                                                     message="Please select the folder where the downloads should be saved.")
            if download_path:
                download_youtube_videos(youtube_url, download_path)

select_folder()
